rust_candidate_command

Function rust_candidate_command 

pub fn rust_candidate_command(program: &Path) -> Command
Build a Command used to invoke the Rust candidate binary.

Tests use this to ensure a consistent base configuration before adding arguments and environment.