pub fn reset_dir(dst: &Path, src: &Path) -> Result<()>Expand description
Replace the contents of dst with a recursive copy of src.
This is used in tests to reset a working directory to a known state without
needing platform-specific rm -rf behavior.