pub fn rust_candidate_command(program: &Path) -> Command
Build a Command used to invoke the Rust candidate binary.
Command
Tests use this to ensure a consistent base configuration before adding arguments and environment.